# MXCHIP Flash Tool

This tool is written by [Snow Yang](yangsw@mxchip.com) for MXCHIP IoT module developer to download firmware into module with J-Link or MX-Link.

The source code is at here: https://github.com/smartsnow/mflash